# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pentest_report_generator']

package_data = \
{'': ['*'], 'pentest_report_generator': ['assets/*']}

install_requires = \
['Jinja2>=3.1.2,<4.0.0',
 'Markdown>=3.4.1,<4.0.0',
 'Pygments>=2.13.0,<3.0.0',
 'bleach>=5.0.1,<6.0.0',
 'click>=8.1.3,<9.0.0',
 'pymdown-extensions>=9.7,<10.0',
 'python-slugify>=6.1.2,<7.0.0',
 'weasyprint>=57.0,<58.0']

entry_points = \
{'console_scripts': ['genpenrep = pentest_report_generator.cli:cli']}

setup_kwargs = {
    'name': 'pentest-report-generator',
    'version': '0.1.6',
    'description': 'Generate penetration testing report from markdown files',
    'long_description': '# pentest-report-generator\n\nGenerate HTML and PDF penetration testing reports from markdown files.\n\n## Usage\n\n```\nUsage: genpenrep [OPTIONS]\n\nOptions:\n  -s, --sources DIRECTORY  Directory with .md source files\n  -o, --output DIRECTORY   Directory to write output files\n  -c, --compress           Create .zip archive with the HTML source files\n  --only-pdf               Do not output HTML files\n  --only-html              Do not output PDF file\n  --help                   Show this message and exit.\n```\n\nYou can see an example penetration test and the output in the `example` directory.\n\n## Setup\n\n```bash\n# Why is pipx better than pip? https://pypa.github.io/pipx/#how-is-it-different-from-pip\npipx install pentest-report-generator\n\npip install pentest-report-generator\n```\n\nThe software is also available as a [Docker container](https://hub.docker.com/r/staticnoise/pentest-report-generator/tags).\n\n```bash\ndocker run -it --rm -v "$PWD/sources:/data" -v "$PWD/output:/output" \'staticnoise/pentest-report-generator\' -s /data -o /output\n```\n\n## Development\n\n```bash\npipx install --editable ./\n```\n\n### Docker\n\n```\npodman login docker.io\npoetry build\n\n# update Dockerfile and bump-up the version number if necessary\npodman build -t docker.io/staticnoise/pentest-report-generator .\n\n# test the created docker container\npodman run -it --rm -v "$PWD/sources:/data:z" -v "$PWD/output:/output:z" \'docker.io/staticnoise/pentest-report-generator\' -s /data -o /output\n\n# publish the Docker image\npodman push docker.io/staticnoise/pentest-report-generator\n```\n\n### Poetry\n\n```bash\npoetry config repositories.pypi https://upload.pypi.org/legacy/\n\n# you will be prompted for password\npoetry config http-basic.pypi staticnoise\n\npoetry build\n\npoetry publish --dry-run\npoetry publish\n```\n\n## License\n\n```\nCopyright (c) 2022-2023 Adam Chovanec\n\nPermission is hereby granted, free of charge, to any person\nobtaining a copy of this software and associated documentation\nfiles (the "Software"), to deal in the Software without\nrestriction, including without limitation the rights to use,\ncopy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the\nSoftware is furnished to do so, subject to the following\nconditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES\nOF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT\nHOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,\nWHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING\nFROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR\nOTHER DEALINGS IN THE SOFTWARE.\n```\n',
    'author': 'Adam Chovanec',
    'author_email': 'business@adamchovanec.cz',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://gitlab.com/staticnoise/pentest-report-generator',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
